@@ -6,9 +6,10 @@ library(stringr)
 
 test_that("computePathways DatabaseConnector", {
   skip("Eunomia [2.0.0] bug")
+  skip_on_cran()
   skip_if_not(ableToRun()$CG)
   globals <- generateCohortTableCG()
-  
+
   expect_message(
     expect_message(
       expect_message(
@@ -28,9 +29,10 @@ test_that("computePathways DatabaseConnector", {
 })
 
 test_that("computePathways CDMConnector", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
   globals <- generateCohortTableCDMC()
-  
+
   expect_message(
     expect_message(
       expect_message(
@@ -39,18 +41,19 @@ test_that("computePathways CDMConnector", {
           cdm = globals$cdm,
           globals$cohortTableName
         ),
-        "Records: 553"
+        ">> Starting on"
       ),
-      "Records: 554"
+      "-- Iteration 1:"
     ),
-    "Records: 8366"
+    "-- treatment construction done"
   )
-  
+
   DBI::dbDisconnect(globals$con, shutdown = TRUE)
 })
 
 test_that("nrow exitCohorts > 0", {
   skip("Eunomia [2.0.0] bug")
+  skip_on_cran()
   skip_if_not(ableToRun()$CG)
   globals <- generateCohortTableCG()
 
@@ -59,7 +62,7 @@ test_that("nrow exitCohorts > 0", {
       .data$cohortName == "Acetaminophen" ~ "exit",
       .default = .data$type
     ))
-  
+
   expect_message(
     computePathways(
       connectionDetails = globals$connectionDetails,
@@ -73,49 +76,8 @@ test_that("nrow exitCohorts > 0", {
 })
 
 # Parameter sweep ----
-test_that("includeTreatments", {
-  skip_if_not(ableToRun()$CDMC)
-  globals <- generateCohortTableCDMC()
-
-  andromeda_startDate <- computePathways(
-    cohorts = globals$cohorts,
-    cohortTableName = globals$cohortTableName,
-    cdm = globals$cdm,
-    includeTreatments = "startDate"
-  )
-
-  andromeda_endDate <- computePathways(
-    cohorts = globals$cohorts,
-    cohortTableName = globals$cohortTableName,
-    cdm = globals$cdm,
-    includeTreatments = "endDate"
-  )
-
-  startDate <- andromeda_startDate$treatmentHistory %>% dplyr::collect()
-  endDate <- andromeda_endDate$treatmentHistory %>% dplyr::collect()
-
-  expect_true(
-    all(startDate$eventStartDate %in% endDate$eventStartDate)
-  )
-
-  expect_true(
-    all(startDate$durationEra %in% endDate$durationEra)
-  )
-
-  expect_error(
-    computePathways(
-      cohorts = globals$cohorts,
-      cohortTableName = globals$cohortTableName,
-      cdm = globals$cdm,
-      includeTreatments = "asdlf"
-    )
-  )
-
-  Andromeda::close(andromeda_startDate)
-  Andromeda::close(andromeda_endDate)
-})
-
-test_that("indexDateOffset", {
+test_that("windowStart", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
   globals <- generateCohortTableCDMC()
 
@@ -124,9 +86,9 @@ test_that("indexDateOffset", {
       cohorts = globals$cohorts,
       cohortTableName = globals$cohortTableName,
       cdm = globals$cdm,
-      indexDateOffset = "0"
+      windowStart = "0"
     ),
-    "Must be of type.+'numeric'"
+    "Must be of type.+'integerish'"
   )
 
   expect_error(
@@ -134,46 +96,47 @@ test_that("indexDateOffset", {
       cohorts = globals$cohorts,
       cohortTableName = globals$cohortTableName,
       cdm = globals$cdm,
-      indexDateOffset = Inf
+      windowStart = Inf
     ),
-    "Must be finite"
+    "Must be of type.+'integerish'"
   )
-  
+
   expect_message(
     computePathways(
       cohorts = globals$cohorts,
       cohortTableName = globals$cohortTableName,
       cdm = globals$cdm,
-      indexDateOffset = 0
+      windowStart = 0
     ),
     "Records: 8366"
   )
-  
+
   expect_message(
     computePathways(
       cohorts = globals$cohorts,
       cohortTableName = globals$cohortTableName,
       cdm = globals$cdm,
-      indexDateOffset = -30
+      windowStart = -30
     ),
     "Records: 8366"
   )
-  
+
   expect_message(
     computePathways(
       cohorts = globals$cohorts,
       cohortTableName = globals$cohortTableName,
       cdm = globals$cdm,
-      indexDateOffset = 30
+      windowStart = 30
     ),
     "Records: 6267"
   )
 })
 
 test_that("minEraDuration", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
   globals <- generateCohortTableCDMC()
-  
+
   expect_error(
     computePathways(
       cohorts = globals$cohorts,
@@ -186,16 +149,17 @@ test_that("minEraDuration", {
 })
 
 test_that("splitEventCohorts", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
   globals <- generateCohortTableCDMC()
-  
+
   andromeda_empty <- computePathways(
     cohorts = globals$cohorts,
     cohortTableName = globals$cohortTableName,
     cdm = globals$cdm,
     splitEventCohorts = NULL
   )
-  
+
   andromeda_Clavulanate <- computePathways(
     cohorts = globals$cohorts,
     cohortTableName = globals$cohortTableName,
@@ -203,12 +167,12 @@ test_that("splitEventCohorts", {
     splitEventCohorts = 4,
     splitTime = 30
   )
-  
+
   empty <- andromeda_empty[["treatmentHistory"]] %>% collect()
   clavulanate <- andromeda_Clavulanate[["treatmentHistory"]] %>% collect()
-  
+
   expect_false(identical(empty$eventCohortId, clavulanate$eventCohortId))
-  
+
   expect_error(
     computePathways(
       cohorts = globals$cohorts,
@@ -218,15 +182,16 @@ test_that("splitEventCohorts", {
     ),
     "Must be of type.+'integerish'"
   )
-  
+
   Andromeda::close(andromeda_Clavulanate)
   Andromeda::close(andromeda_empty)
 })
 
 test_that("splitTime", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
   globals <- generateCohortTableCDMC()
-  
+
   expect_error(
     computePathways(
       cohorts = globals$cohorts,
@@ -239,23 +204,24 @@ test_that("splitTime", {
 })
 
 test_that("eraCollapseSize", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
   globals <- generateCohortTableCDMC()
-  
+
   andromeda_0 <- computePathways(
     cohorts = globals$cohorts,
     cohortTableName = globals$cohortTableName,
     cdm = globals$cdm,
     eraCollapseSize = 0
   )
-  
+
   andromeda_10000 <- computePathways(
     cohorts = globals$cohorts,
     cohortTableName = globals$cohortTableName,
     cdm = globals$cdm,
     eraCollapseSize = 10000
   )
-  
+
   expect_error(
     computePathways(
       cohorts = globals$cohorts,
@@ -265,15 +231,16 @@ test_that("eraCollapseSize", {
     ),
     " Must be of type.+'numeric'"
   )
-  
+
   Andromeda::close(andromeda_0)
   Andromeda::close(andromeda_10000)
 })
 
 test_that("combinationWindow", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
   globals <- generateCohortTableCDMC()
-  
+
   expect_error(
     suppressWarnings(
       computePathways(
@@ -288,33 +255,32 @@ test_that("combinationWindow", {
 })
 
 test_that("minPostCombinationDuration: 30", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomiaDir())
-  
+
   cohorts <- data.frame(
     cohortId = c(1, 2, 3),
     cohortName = c("X", "A", "B"),
     type = c("target", "event", "event")
   )
-  
+
   cohort_table <- dplyr::tribble(
     ~cohort_definition_id, ~subject_id, ~cohort_start_date,    ~cohort_end_date,
     1,                     5,           as.Date("2014-01-01"), as.Date("2015-01-01"),
     2,                     5,           as.Date("2014-01-01"), as.Date("2014-03-01"),
     3,                     5,           as.Date("2014-01-10"), as.Date("2014-03-15")
   )
-  
+
   copy_to(con, cohort_table, overwrite = TRUE)
-  
+
   cdm <- cdmFromCon(con, cdmSchema = "main", writeSchema = "main", cohortTables = "cohort_table")
-  
+
   ## 30 ----
   andromeda <- TreatmentPatterns::computePathways(
     cohorts = cohorts,
     cohortTableName = "cohort_table",
     cdm = cdm,
-    includeTreatments = "startDate",
-    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 3,
     combinationWindow = 30,
@@ -322,27 +288,26 @@ test_that("minPostCombinationDuration: 30", {
     filterTreatments = "All",
     maxPathLength = 5
   )
-  
+
   result <- TreatmentPatterns::export(andromeda, minCellCount = 1)
-  
+
   treatmentPaths <- result$treatment_pathways
-  
+
   pathway <- treatmentPaths %>%
     dplyr::filter(
       .data$age == "all",
       .data$sex == "all",
-      .data$index_year == "all") %>%
+      .data$index_year == "all"
+    ) %>%
     dplyr::pull(.data$pathway)
-  
+
   expect_identical(pathway, "A+B")
-  
+
   ## 12 ----
   andromeda <- TreatmentPatterns::computePathways(
     cohorts = cohorts,
     cohortTableName = "cohort_table",
     cdm = cdm,
-    includeTreatments = "startDate",
-    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 3,
     combinationWindow = 30,
@@ -350,28 +315,27 @@ test_that("minPostCombinationDuration: 30", {
     filterTreatments = "All",
     maxPathLength = 5
   )
-  
+
   result <- TreatmentPatterns::export(andromeda, minCellCount = 1)
-  
+
   treatmentPaths <- result$treatment_pathways
-  
+
   pathway <- treatmentPaths %>%
     dplyr::filter(
       .data$age == "all",
       .data$sex == "all",
-      .data$index_year == "all") %>%
+      .data$index_year == "all"
+    ) %>%
     dplyr::pull(.data$pathway)
-  
+
   expect_identical(pathway, "A+B-B")
-  
-  
+
+
   ## 8 ----
   andromeda <- TreatmentPatterns::computePathways(
     cohorts = cohorts,
     cohortTableName = "cohort_table",
     cdm = cdm,
-    includeTreatments = "startDate",
-    indexDateOffset = 0,
     minEraDuration = 0,
     eraCollapseSize = 3,
     combinationWindow = 30,
@@ -379,27 +343,29 @@ test_that("minPostCombinationDuration: 30", {
     filterTreatments = "All",
     maxPathLength = 5
   )
-  
+
   result <- TreatmentPatterns::export(andromeda, minCellCount = 1)
-  
+
   treatmentPaths <- result$treatment_pathways
-  
+
   pathway <- treatmentPaths %>%
     dplyr::filter(
       .data$age == "all",
       .data$sex == "all",
-      .data$index_year == "all") %>%
+      .data$index_year == "all"
+    ) %>%
     dplyr::pull(.data$pathway)
-  
+
   expect_identical(pathway, "A-A+B-B")
-  
+
   DBI::dbDisconnect(con)
 })
 
 test_that("filterTreatments", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
   globals <- generateCohortTableCDMC()
-  
+
   expect_error(
     computePathways(
       cohorts = globals$cohorts,
@@ -409,7 +375,7 @@ test_that("filterTreatments", {
     ),
     "Must be a subset of"
   )
-  
+
   first <- computePathways(
     cohorts = globals$cohorts,
     cohortTableName = globals$cohortTableName,
@@ -439,14 +405,14 @@ test_that("filterTreatments", {
 
   allTH <- all$treatmentHistory %>%
     dplyr::collect()
-  
+
   # Check names
   expect_identical(
     sort(names(firstTH)),
     sort(names(changesTH)),
     sort(names(allTH))
   )
-  
+
   # eventCohortId
   expect_identical(
     "character",
@@ -454,7 +420,7 @@ test_that("filterTreatments", {
     class(changesTH$eventCohortId),
     class(allTH$eventCohortId)
   )
-  
+
   expect_contains(
     expected = c(
       class(firstTH$personId),
@@ -463,49 +429,49 @@ test_that("filterTreatments", {
     ),
     object = c("integer", "numeric")
   )
-  
+
   expect_identical(
     "numeric",
     class(firstTH$indexYear),
     class(changesTH$indexYear),
     class(allTH$indexYear)
   )
-  
+
   expect_identical(
     "numeric",
     class(firstTH$eventStartDate),
     class(changesTH$eventStartDate),
     class(allTH$eventStartDate)
   )
-  
+
   expect_identical(
     "numeric",
     class(firstTH$eventEndDate),
     class(changesTH$eventStartDate),
     class(allTH$eventEndDate)
   )
-  
+
   expect_identical(
     "numeric",
     class(firstTH$age),
     class(changesTH$age),
     class(allTH$age)
   )
-  
+
   expect_identical(
     "character",
     class(firstTH$sex),
     class(changesTH$sex),
     class(allTH$sex)
   )
-  
+
   expect_identical(
     "numeric",
     class(firstTH$durationEra),
     class(changesTH$durationEra),
     class(allTH$durationEra)
   )
-  
+
   expect_identical(
     "numeric",
     class(firstTH$sortOrder),
@@ -523,141 +489,134 @@ test_that("filterTreatments", {
     class(changesTH$eventCohortName),
     class(allTH$eventCohortName)
   )
-  
+
   expect_false(any(is.na(firstTH)))
   expect_false(any(is.na(changesTH)))
   expect_false(any(is.na(allTH)))
-  
+
   expect_false(any(is.null(firstTH)))
   expect_false(any(is.null(changesTH)))
   expect_false(any(is.null(allTH)))
-  
-  expect_true(nrow(firstTH) == 553)
-  expect_true(nrow(changesTH) == 554)
-  expect_true(nrow(allTH) == 554)
 
   expect_true(Andromeda::isAndromeda(first))
   expect_true(Andromeda::isAndromeda(changes))
   expect_true(Andromeda::isAndromeda(all))
-  
+
   Andromeda::close(first)
   Andromeda::close(changes)
   Andromeda::close(all)
 })
 
 test_that("FRFS combination", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomiaDir())
-  
+
   cohorts <- data.frame(
     cohortId = c(1, 2, 3),
     cohortName = c("X", "A", "B"),
     type = c("target", "event", "event")
   )
-  
+
   cohort_table <- dplyr::tribble(
     ~cohort_definition_id, ~subject_id, ~cohort_start_date, ~cohort_end_date,
-    
     1, 5, as.Date("2017-08-03"), as.Date("2018-08-02"),
     3, 5, as.Date("2017-11-26"), as.Date("2018-04-10"),
     2, 5, as.Date("2018-02-26"), as.Date("2018-04-24"),
-    
     1, 7, as.Date("2015-10-20"), as.Date("2018-06-28"),
     2, 7, as.Date("2017-12-04"), as.Date("2018-04-30")
   )
-  
+
   copy_to(con, cohort_table, overwrite = TRUE)
-  
+
   cdm <- cdmFromCon(con, cdmSchema = "main", writeSchema = "main", cohortTables = "cohort_table")
-  
+
   andromeda <- computePathways(
     cohorts = cohorts,
-    cohortTableName = 'cohort_table',
+    cohortTableName = "cohort_table",
     cdm = cdm,
     tempEmulationSchema = NULL,
-    includeTreatments = "startDate",
-    indexDateOffset = 0,
     minEraDuration = 30,
     eraCollapseSize = 30,
     combinationWindow = 30,
     minPostCombinationDuration = 30,
     filterTreatments = "All",
-    maxPathLength = 5)
-  
+    maxPathLength = 5
+  )
+
   nFRFS <- andromeda$addRowsFRFS_1 %>%
     dplyr::collect() %>%
     nrow()
-  
+
   nLRFS <- andromeda$addRowsLRFS_1 %>%
     dplyr::collect() %>%
     nrow()
-  
+
   expect_equal(nFRFS, 1)
   expect_equal(nLRFS, 0)
-  
+
   DBI::dbDisconnect(con)
 })
 
 test_that("LRFS combination", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
   con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomiaDir())
-  
+
   cohorts <- data.frame(
     cohortId = c(1, 2, 3),
     cohortName = c("X", "A", "B"),
     type = c("target", "event", "event")
   )
-  
+
   cohort_table <- dplyr::tribble(
     ~cohort_definition_id, ~subject_id, ~cohort_start_date, ~cohort_end_date,
-    
     1, 5, as.Date("2017-08-03"), as.Date("2018-08-02"),
     3, 5, as.Date("2017-11-26"), as.Date("2018-04-10"),
     2, 5, as.Date("2018-01-26"), as.Date("2018-03-24"),
-    
     1, 7, as.Date("2015-10-20"), as.Date("2018-06-28"),
     2, 7, as.Date("2017-12-04"), as.Date("2018-04-30")
   )
-  
+
   copy_to(con, cohort_table, overwrite = TRUE)
-  
+
   cdm <- cdmFromCon(con, cdmSchema = "main", writeSchema = "main", cohortTables = "cohort_table")
-  
+
   andromeda <- computePathways(
     cohorts = cohorts,
-    cohortTableName = 'cohort_table',
+    cohortTableName = "cohort_table",
     cdm = cdm,
     tempEmulationSchema = NULL,
-    includeTreatments = "startDate",
-    indexDateOffset = 0,
     minEraDuration = 30,
     eraCollapseSize = 30,
     combinationWindow = 30,
     minPostCombinationDuration = 30,
     filterTreatments = "All",
-    maxPathLength = 5)
-  
+    maxPathLength = 5
+  )
+
   nFRFS <- andromeda$addRowsFRFS_1 %>%
     dplyr::collect() %>%
     nrow()
-  
+
   nLRFS <- andromeda$addRowsLRFS_1 %>%
     dplyr::collect() %>%
     nrow()
-  
+
   expect_equal(nFRFS, 0)
   expect_equal(nLRFS, 1)
-  
+
   DBI::dbDisconnect(con)
 })
 
 test_that("No target records", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
-  
+
   params <- suppressWarnings(generateCohortTableCDMC())
-  
+
   params$cohorts$cohortId[8] <- 9
-  
+
   expect_warning({
     outputEnv <- computePathways(
       cohorts = params$cohorts,
@@ -665,13 +624,14 @@ test_that("No target records", {
       cdm = params$cdm
     )
   })
-  
+
   expect_true(nrow(outputEnv$treatmentHistory %>% collect()) == 0)
-  
+
   DBI::dbDisconnect(params$con, shutdown = TRUE)
 })
 
 test_that("Empty cohort table", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
 
   params <- suppressWarnings(generateCohortTableCDMC())
@@ -687,19 +647,20 @@ test_that("Empty cohort table", {
       cdm = params$cdm
     )
   })
-  
+
   expect_true(nrow(outputEnv$treatmentHistory %>% collect()) == 0)
-  
+
   DBI::dbDisconnect(params$con, shutdown = TRUE)
 })
 
 test_that("No target defined", {
+  skip_on_cran()
   skip_if_not(ableToRun()$CDMC)
 
   params <- suppressWarnings(generateCohortTableCDMC())
-  
+
   params$cohorts$type <- rep("event", 8)
-  
+
   expect_error({
     outputEnv <- computePathways(
       cohorts = params$cohorts,
@@ -712,6 +673,7 @@ test_that("No target defined", {
 })
 
 test_that("Attrition", {
+  skip_on_cran()
   skip_on_os(os = "linux")
   skip_if_not(ableToRun()$CDMC)
   skip_if_not(ableToRun()$CG)
